from ngsolve import *
from netgen.geom2d import SplineGeometry

geo = SplineGeometry()
pnts = [ (0,0), (0.5,0), (1,0), (1,1), (0.5,1), (0,1) ]
pind = [ geo.AppendPoint(*pnt) for pnt in pnts ]

geo.Append(['line',pind[0],pind[1]],leftdomain=1,rightdomain=0,bc="bottom")
geo.Append(['line',pind[1],pind[2]],leftdomain=2,rightdomain=0,bc="bottom")
geo.Append(['line',pind[2],pind[3]],leftdomain=2,rightdomain=0,bc="right")
geo.Append(['line',pind[3],pind[4]],leftdomain=2,rightdomain=0,bc="top")
geo.Append(['line',pind[4],pind[5]],leftdomain=1,rightdomain=0,bc="top")
geo.Append(['line',pind[5],pind[0]],leftdomain=1,rightdomain=0,bc="left")
geo.Append(['line',pind[1],pind[4]],leftdomain=1,rightdomain=2,bc="interface")

geo.SetMaterial(1, "left_dom")
geo.SetMaterial(2, "right_dom")

mesh = Mesh( geo.GenerateMesh(maxh=0.1) )
Draw(mesh)


fes1 = H1(mesh, order=1, definedon= "left_dom", dirichlet="left|top|bottom")
fes2 = H1(mesh, order=1, definedon= "right_dom", dirichlet="right|top|bottom")

gfu1 = GridFunction(fes1)
gfu2 = GridFunction(fes2)

gfu1.Set(0.3*x)
gfu2.Set(0.3*y)

gfu = CoefficientFunction( [gfu1 if mat == "left_dom" else gfu2 for mat in mesh.GetMaterials()] )
Draw(gfu, mesh, "gfu")

SetVisualization(deformation=True)
